==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CalloutSeriesSelectingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutSeriesSelectingEventArgsDescription } from "./CalloutSeriesSelectingEventArgsDescription";
/**
 * @hidden
 */
var CalloutSeriesSelectingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutSeriesSelectingEventArgsDescriptionMetadata, _super);
    function CalloutSeriesSelectingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutSeriesSelectingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutSeriesSelectingEventArgsDescriptionMetadata.a == null) {
            CalloutSeriesSelectingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutSeriesSelectingEventArgsDescriptionMetadata.c(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
        }
        if (a.g(CalloutSeriesSelectingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutSeriesSelectingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("Series", "(j:_internalSeries)ExportedType:Series");
        a.item("SeriesName", "String");
    };
    CalloutSeriesSelectingEventArgsDescriptionMetadata.d = function (a) {
        CalloutSeriesSelectingEventArgsDescriptionMetadata.b(a);
        a.u("CalloutSeriesSelectingEventArgs", function () { return new CalloutSeriesSelectingEventArgsDescription(); });
        a.t("CalloutSeriesSelectingEventArgs", CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
    };
    CalloutSeriesSelectingEventArgsDescriptionMetadata.$t = markType(CalloutSeriesSelectingEventArgsDescriptionMetadata, 'CalloutSeriesSelectingEventArgsDescriptionMetadata');
    CalloutSeriesSelectingEventArgsDescriptionMetadata.a = null;
    return CalloutSeriesSelectingEventArgsDescriptionMetadata;
}(Base));
export { CalloutSeriesSelectingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CalloutSeriesSelectingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutSeriesSelectingEventArgsDescription } from "./CalloutSeriesSelectingEventArgsDescription";
/**
 * @hidden
 */
var CalloutSeriesSelectingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutSeriesSelectingEventArgsDescriptionMetadata, _super);
    function CalloutSeriesSelectingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutSeriesSelectingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutSeriesSelectingEventArgsDescriptionMetadata.a == null) {
            CalloutSeriesSelectingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutSeriesSelectingEventArgsDescriptionMetadata.c(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
        }
        if (a.j(CalloutSeriesSelectingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutSeriesSelectingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("Series", "(j:_internalSeries)ExportedType:Series");
        a.item("SeriesName", "String");
    };
    CalloutSeriesSelectingEventArgsDescriptionMetadata.d = function (a) {
        CalloutSeriesSelectingEventArgsDescriptionMetadata.b(a);
        a.aa("CalloutSeriesSelectingEventArgs", function () { return new CalloutSeriesSelectingEventArgsDescription(); });
        a.z("CalloutSeriesSelectingEventArgs", CalloutSeriesSelectingEventArgsDescriptionMetadata.a);
    };
    CalloutSeriesSelectingEventArgsDescriptionMetadata.$t = markType(CalloutSeriesSelectingEventArgsDescriptionMetadata, 'CalloutSeriesSelectingEventArgsDescriptionMetadata');
    CalloutSeriesSelectingEventArgsDescriptionMetadata.a = null;
    return CalloutSeriesSelectingEventArgsDescriptionMetadata;
}(Base));
export { CalloutSeriesSelectingEventArgsDescriptionMetadata };
